/**
 * Recursively scans the list of directories for files with one of the provided
 * extensions.
 *
 * @param baseDirs Directories to search for files
 * @param extensions List of valid extensions that files may have
 */
export default function recursiveWalk(baseDirs: string[], extensions: string[]): Promise<string[]>;
